<?php class basereport extends baseobject {

    /**
     * @param array $request
     * @return null
     */
    public static function getAll(array $request=array()): ?array {
        return null;
    }

}